==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/mediabox/lang/mediabox_es.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mediabox?lang_cible=es
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_reinitialiser' => 'Reinicializar',
	'boxstr_close' => 'Cerrar',
	'boxstr_current' => '@current@/@total@',
	'boxstr_dialog_title_default' => 'Cuadro de diálogo',
	'boxstr_dialog_title_medias' => 'Visualización de medios',
	'boxstr_loading' => 'Cargando...',
	'boxstr_next' => 'Siguiente',
	'boxstr_press_escape_to_close' => 'Pulse ’Esc’ para cerrar',
	'boxstr_previous' => 'Anterior',
	'boxstr_slideshowStart' => 'Presentación',
	'boxstr_slideshowStop' => 'Detener',
	'boxstr_zoom' => 'Zoom',

	// E
	'explication_selecteur' => 'Indica los selectores que activarán la caja (Expresión CSS o selector jQuery)',
	'explication_selecteur_galerie' => 'Indica los selectores que activarán la caja en forma de galería. (Expresión CSS o selector jQuery)',
	'explication_splash_url' => 'Indica la URL de un contenido multimedia que se mostrará en una caja la primera vez que un visitante accede al sitio público',
	'explication_traiter_toutes_images' => '¿Insertar una caja en todas las imágenes?',

	// I
	'info_box_lity_nom_skin__simple_dark' => 'Oscuro por defecto',
	'info_box_lity_nom_skin__simple_white' => 'Claro por defecto',
	'info_box_lity_nom_skin_fancybox' => 'Estilo Fancybox',
	'info_box_lity_nom_skin_thickbox' => 'Estilo Thickbox',

	// L
	'label_active' => 'Activar mediabox en el espacio público',
	'label_apparence' => 'Apariencia',
	'label_aucun_style' => 'No usar ningún estilo por omisión',
	'label_choix_transition_elastic' => 'Elástico',
	'label_choix_transition_fade' => 'transición progresiva',
	'label_choix_transition_none' => 'Ninguno',
	'label_defaultcaptionstate' => 'Título predeterminado',
	'label_defaultcaptionstate_expanded' => 'Expandir el título predeterminado',
	'label_defaultcaptionstate_min' => 'Contraer el título predeterminado',
	'label_maxheight' => 'Alto máximo (% o px)',
	'label_maxwidth' => 'Ancho máximo (% o px)',
	'label_minheight' => 'Alto minimo (% o px)',
	'label_minwidth' => 'Ancho minimo (% o px)',
	'label_opacite' => 'Opacidad de fondo',
	'label_selecteur_commun' => 'Selector general',
	'label_selecteur_galerie' => 'Selector de galería',
	'label_skin' => 'Estilo visual',
	'label_slideshow_speed' => 'Duración de las diapositivas (ms)',
	'label_speed' => 'Velocidad de transición (ms)',
	'label_splash' => 'Caja Splash',
	'label_splash_height' => 'Alto (% o px)',
	'label_splash_url' => 'URL del contenido',
	'label_splash_width' => 'Ancho (% o px)',
	'label_traiter_toutes_images' => 'Imágenes',
	'label_transition' => 'Efecto de transición',

	// T
	'titre_menu_box' => 'Caja Multimedia',
	'titre_page_configurer_box' => 'Configuracíon de la caja multimedia'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/mediabox/lang/mediabox_es.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mediabox?lang_cible=es
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_reinitialiser' => 'Reinicializar',
	'boxstr_close' => 'Cerrar',
	'boxstr_current' => '@current@/@total@',
	'boxstr_dialog_title_default' => 'Cuadro de diálogo',
	'boxstr_dialog_title_medias' => 'Visualización de medios',
	'boxstr_loading' => 'Cargando...',
	'boxstr_next' => 'Siguiente',
	'boxstr_press_escape_to_close' => 'Pulse ’Esc’ para cerrar',
	'boxstr_previous' => 'Anterior',
	'boxstr_slideshowStart' => 'Presentación',
	'boxstr_slideshowStop' => 'Detener',
	'boxstr_zoom' => 'Zoom',

	// E
	'explication_selecteur' => 'Indica los selectores que activarán la caja (Expresión CSS o selector jQuery)',
	'explication_selecteur_galerie' => 'Indica los selectores que activarán la caja en forma de galería. (Expresión CSS o selector jQuery)',
	'explication_splash_url' => 'Indica la URL de un contenido multimedia que se mostrará en una caja la primera vez que un visitante accede al sitio público',
	'explication_traiter_toutes_images' => '¿Insertar una caja en todas las imágenes?',

	// I
	'info_box_lity_nom_skin__simple_dark' => 'Oscuro por defecto',
	'info_box_lity_nom_skin__simple_white' => 'Claro por defecto',
	'info_box_lity_nom_skin_fancybox' => 'Estilo Fancybox',
	'info_box_lity_nom_skin_thickbox' => 'Estilo Thickbox',

	// L
	'label_active' => 'Activar mediabox en el espacio público',
	'label_apparence' => 'Apariencia',
	'label_aucun_style' => 'No usar ningún estilo por omisión',
	'label_choix_transition_elastic' => 'Elástico',
	'label_choix_transition_fade' => 'transición progresiva',
	'label_choix_transition_none' => 'Ninguno',
	'label_defaultcaptionstate' => 'Título predeterminado',
	'label_defaultcaptionstate_expanded' => 'Expandir el título predeterminado',
	'label_defaultcaptionstate_min' => 'Contraer el título predeterminado',
	'label_maxheight' => 'Alto máximo (% o px)',
	'label_maxwidth' => 'Ancho máximo (% o px)',
	'label_minheight' => 'Alto minimo (% o px)',
	'label_minwidth' => 'Ancho minimo (% o px)',
	'label_opacite' => 'Opacidad de fondo',
	'label_selecteur_commun' => 'Selector general',
	'label_selecteur_galerie' => 'Selector de galería',
	'label_skin' => 'Estilo visual',
	'label_slideshow_speed' => 'Duración de las diapositivas (ms)',
	'label_speed' => 'Velocidad de transición (ms)',
	'label_splash' => 'Caja Splash',
	'label_splash_height' => 'Alto (% o px)',
	'label_splash_url' => 'URL del contenido',
	'label_splash_width' => 'Ancho (% o px)',
	'label_traiter_toutes_images' => 'Imágenes',
	'label_transition' => 'Efecto de transición',

	// T
	'titre_menu_box' => 'Caja Multimedia',
	'titre_page_configurer_box' => 'Configuracíon de la caja multimedia',
];
